@@ -20,7 +20,7 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
   n <- length(u)  ## sample size
   x <- cbind( cos(u), sin(u) )
   disa <- tcrossprod(x)
-  diag(disa) <- 1
+  diag(disa) <-  -Inf
   expa <- exp(disa)
 
   if ( is.null(h) ) {
@@ -32,11 +32,11 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
       k <- Directional::circ.summary(u, rads = TRUE, plot = FALSE)$kappa
       h <- ( ( k * n * ( 2 * besselI(2 * k, 1) + 3 * k * besselI(2 * k, 2)) ) / ( 4 * pi^0.5 * besselI(k, 0)^2 ) )^0.4
     } else if (thumb == "none") {
-      h <- as.numeric( vmkde.tune(u, low = 0.1, up = 1)[1] )
+      h <- as.numeric( Directional::vmkde.tune(u, low = 0.1, up = 1)[1] )
     }
 
   } else h <- h
 
-  f <- Rfast::rowsums( expa^h ) / ( n * 2 * pi * besselI(h, 0) )
+  f <- Rfast::rowsums( expa^h ) / ( (n - 1) * 2 * pi * besselI(h, 0) )
   list( h = h, f = f )
 }
